@@ -9,7 +9,7 @@ test_that("Survival data manipulation", {
                      levels=0:3, labels=c("censored", "death", "competing event 1", "competing event 2"))
     ys <- survival::Surv(pmin(failure_times, censoring_times), events)
 
-    expect_equal(dichotomize(ys, to_factor=FALSE), ys[,"status"])
+    expect_equal(dichotomize(ys, to_factor=FALSE), ys[,"status"], tolerance=1e-3)
     expect_true(all(
         sign(table(dichotomize(ys), useNA="always") -
              table(dichotomize(ys, 30), useNA="always")) *
@@ -19,5 +19,5 @@ test_that("Survival data manipulation", {
     ys[1:2, "time"] <- NA
     ys[c(1, 3), "status"] <- NA
     expect_true(all(is.na(dichotomize(ys[1:3]))))
-    expect_equal(dichotomize(ys[1:3], time=0, to_factor=FALSE), c(NA, NA, 0))
+    expect_equal(dichotomize(ys[1:3], time=0, to_factor=FALSE), c(NA, NA, 0), tolerance=1e-3)
 })
